@@ -541,10 +541,16 @@ struct ndpi_flow_tcp_struct {
     u_int32_t telnet_stage:2; // 0 - 2
 
     /* NDPI_PROTOCOL_SSL */
+    void* tls_srv_cert_fingerprint_ctx;
+
     u_int8_t ssl_seen_client_cert:1,
              ssl_seen_server_cert:1,
              ssl_seen_certificate:1,
-             ssl_stage:2; // 0 - 5
+             tls_srv_cert_fingerprint_found:1,
+             tls_srv_cert_fingerprint_processed:1,
+             ssl_stage:2, _pad:1; // 0 - 5
+    int16_t tls_record_offset, tls_fingerprint_len; /* Need to be signed */
+    u_int8_t tls_sha1_certificate_fingerprint[20];
 
     /* NDPI_PROTOCOL_POSTGRES */
     u_int32_t postgres_stage:3;
@@ -1008,6 +1014,7 @@ struct ndpi_flow_struct {
             struct {
                 u_int16_t ssl_version;
                 char client_certificate[64], server_certificate[64], server_organization[64];
+                u_int32_t notBefore, notAfter;
                 char ja3_client[33], ja3_server[33];
                 u_int16_t version, server_cipher;
                 ndpi_cipher_weakness server_unsafe_cipher;
@@ -1022,6 +1029,7 @@ struct ndpi_flow_struct {
 
         struct {
             char client_signature[48], server_signature[48];
+            char hassh_client[33], hassh_server[33];
         } ssh;
 
         struct {
