@@ -32,6 +32,9 @@
 #define DB_HOST_INT     "host_int"
 #define DB_HOST_INT_LEN (sizeof(DB_HOST_INT) - 1)
 
+#define DB_BUS17CMD     "Bus17Cmd"
+#define DB_BUS17CMD_LEN (sizeof(DB_BUS17CMD) - 1)
+
 static void ndpi_int_dropbox_add_connection(
         struct ndpi_detection_module_struct *ndpi_struct,
         struct ndpi_flow_struct *flow,
@@ -47,18 +50,24 @@ static void ndpi_check_dropbox(
     struct ndpi_packet_struct *packet = &flow->packet;
     u_int32_t payload_len = packet->payload_packet_len;
 
-    if(packet->udp != NULL) {
-        u_int16_t dropbox_port = htons(DB_LSP_PORT);
+    if (packet->udp != NULL) {
+        if (packet->udp->source == htons(DB_LSP_PORT)) {
+            if (payload_len > DB_HOST_INT_LEN) {
+                if (ndpi_strnstr((const char *)packet->payload,
+                            "\"" DB_HOST_INT "\"", payload_len) != NULL) {
 
-        if((packet->udp->source == dropbox_port)
-                && (packet->udp->dest == dropbox_port)) {
-            if(payload_len > DB_HOST_INT_LEN) {
-                /* XXX: Is payload guaranteed to be NULL-terminated?
-                 * If not, the following call to strstr() would be run out-of-bounds.
-                 * */
-                if(strstr((const char *)packet->payload, "\"host_int\"") != NULL) {
+                    NDPI_LOG_INFO(ndpi_struct, "found dropbox (host_int)\n");
+                    ndpi_int_dropbox_add_connection(ndpi_struct, flow, 0);
+                    return;
+                }
+            }
+        }
+        else {
+            if (payload_len > DB_BUS17CMD_LEN) {
+                if (ndpi_strnstr((const char *)packet->payload,
+                            DB_BUS17CMD, payload_len) != NULL) {
 
-                    NDPI_LOG_INFO(ndpi_struct, "found dropbox\n");
+                    NDPI_LOG_INFO(ndpi_struct, "found dropbox (Bus17Cmd)\n");
                     ndpi_int_dropbox_add_connection(ndpi_struct, flow, 0);
                     return;
                 }
