@@ -1,5 +1,5 @@
 // Netify Agent
-// Copyright (C) 2015-2019 eGloo Incorporated <http://www.egloo.ca>
+// Copyright (C) 2015-2020 eGloo Incorporated <http://www.egloo.ca>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -530,6 +530,14 @@ bool ndFlow::has_mdns_answer(void)
     );
 }
 
+bool ndFlow::has_ssdp_headers(void)
+{
+    return (
+        detected_protocol.master_protocol == NDPI_PROTOCOL_SSDP &&
+        ssdp.headers.size()
+    );
+}
+
 void ndFlow::print(const char *tag, struct ndpi_detection_module_struct *ndpi)
 {
     char *p = NULL, buffer[64];
@@ -979,6 +987,12 @@ void ndFlow::json_encode(json &j,
         j["mdns"]["answer"] = mdns.answer;
     }
 
+    if (has_ssdp_headers()) {
+
+        j["ssdp"] = ssdp.headers;
+
+    }
+
     j["first_seen_at"] = ts_first_seen;
     j["first_update_at"] = ts_first_update;
     j["last_seen_at"] = ts_last_seen;
