@@ -1,5 +1,5 @@
 // Netify Agent
-// Copyright (C) 2015-2019 eGloo Incorporated <http://www.egloo.ca>
+// Copyright (C) 2015-2020 eGloo Incorporated <http://www.egloo.ca>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -143,7 +143,7 @@ pthread_mutex_t *nd_printf_mutex = NULL;
 static void nd_usage(int rc = 0, bool version = false)
 {
     fprintf(stderr, "%s\n", nd_get_version_and_features().c_str());
-    fprintf(stderr, "Copyright (C) 2015-2019 eGloo Incorporated\n"
+    fprintf(stderr, "Copyright (C) 2015-2020 eGloo Incorporated\n"
             "[%s %s]\n", GIT_RELEASE, GIT_DATE);
     if (version) {
         fprintf(stderr, "\nThis application uses nDPI v%s\n"
@@ -1708,30 +1708,33 @@ static void nd_status(void)
     ndJsonStatus json_status;
     bool json_status_valid = false;
 
-    if (nd_pid > 0) {
-        try {
-            string status;
-            if (nd_file_load(ND_JSON_FILE_STATUS, status) < 0) {
-                fprintf(stderr,
-                    "%s-%s agent run-time status could not be determined.\n",
-                    ND_C_YELLOW, ND_C_RESET
-                );
-            }
-            else {
-                json_status.Parse(status);
-                json_status_valid = true;
-            }
+    try {
+        string status;
+        if (nd_file_load(ND_JSON_FILE_STATUS, status) < 0) {
+            fprintf(stderr,
+                "%s-%s agent run-time status could not be determined.\n",
+                ND_C_YELLOW, ND_C_RESET
+            );
         }
-        catch (runtime_error &e) {
-            fprintf(stderr, "%s-%s agent run-time status exception: %s%s%s\n",
-                ND_C_RED, ND_C_RESET, ND_C_RED, e.what(), ND_C_RESET);
+        else {
+            json_status.Parse(status);
+            json_status_valid = true;
         }
     }
+    catch (runtime_error &e) {
+        fprintf(stderr, "%s-%s agent run-time status exception: %s%s%s\n",
+            ND_C_RED, ND_C_RESET, ND_C_RED, e.what(), ND_C_RESET);
+    }
 
     if (json_status_valid) {
         char timestamp[64];
         struct tm *tm_local = localtime(&json_status.timestamp);
 
+        if (nd_pid <= 0) {
+            fprintf(stderr, "%sThe following information may be out-dated:%s\n",
+                ND_C_YELLOW, ND_C_RESET);
+        }
+
         if (strftime(timestamp, sizeof(timestamp), "%c", tm_local) > 0) {
             fprintf(stderr, "%s-%s agent timestamp: %s\n",
                 ND_C_GREEN, ND_C_RESET, timestamp);
